==> wildgram-0.0.3.tar.gz: wildgram-0.0.3/README.md <==
wildgram tokenizes english text into "wild"-grams (tokens of varying word count)
that match closely to the the natural pauses of conversation. I originally built
it as the first step in an abstraction pipeline for medical language: since
medical concepts tend to be phrases of varying lengths, bag-of-words or bigrams
doesn't really cut it.

Wildgrams works by measuring the size of the noise (stopwords, punctuation, and
whitespace) and breaks up the text against noise of a certain size
(it varies slightly depending on the noise).
Some examples:
"rats, bats, and vats" -> ["rats","bats", "vats"]
"I dreamed a dream in time gone by" -> ["i dreamed","dream", "time gone"]

Because this is originally for a medical abstraction, some of the stop words include
words like "denied", "describe" which tend to signify a change
in topic in medical notes. Some of these words are separated into their own topics (since they have clinical meaning),
while others are removed entirely.
Two examples:
"patient denies consuming alcohol" -> ["patient", "denies", "consuming alcohol"]
"patient describes consuming alcohol" -> ["patient", "consuming alcohol"]

Also note that it doesn't strictly tokenize each token like so:
"I dreamed a dream in time gone by" -> [("i","dreamed"),("dream"), ("time","gone")]

Final note: I do not include "of" in the stop word list, because there are quite a few
medical concepts that have of in the middle (e.g. "shortness of breath").


Example code:

```python
from wildgram import wildgram
tokens, ranges = wildgram("and was beautiful")
#tokens -- the wildgram tokens
#ranges -- a list of tuples, the ith tuple has the start and end indexes for the ith wildgram
print(tokens, ranges) #["beautiful"], [(8, 17)]
```
That's all folks!

==> wildgram-0.0.4.tar.gz: wildgram-0.0.4/README.md <==
wildgram tokenizes english text into "wild"-grams (tokens of varying word count)
that match closely to the the natural pauses of conversation. I originally built
it as the first step in an abstraction pipeline for medical language: since
medical concepts tend to be phrases of varying lengths, bag-of-words or bigrams
doesn't really cut it.

Wildgrams works by measuring the size of the noise (stopwords, punctuation, and
whitespace) and breaks up the text against noise of a certain size
(it varies slightly depending on the noise).
Some examples:
"rats, bats, and vats" -> ["rats","bats", "vats"]
"I dreamed a dream in time gone by" -> ["i dreamed","dream", "time gone"]

Because this is originally for a medical abstraction, some of the stop words include
words like "denied", "describe" which tend to signify a change
in topic in medical notes. Some of these words are separated into their own topics
(since they have clinical meaning), while others are removed entirely.
Numbers (0.1, 1.0, 3) are an example of the latter.
Words with digits that have other punctuation or characters
(e.g. potentially ids like CS123123 or time like 12:30)
are left alone as potentially part of a larger phrase.

Two examples:
"patient denies consuming alcohol" -> ["patient", "denies", "consuming alcohol"]
"patient describes consuming alcohol" -> ["patient", "consuming alcohol"]

Also note that it doesn't strictly tokenize each token like so:
"I dreamed a dream in time gone by" -> [("i","dreamed"),("dream"), ("time","gone")]

Final note: I do not include "of" in the stop word list, because there are quite a few
medical concepts that have of in the middle (e.g. "shortness of breath"). I'm
debating whether to change this to the following
"shortness of breath" -> ["shortness", "shortness of breath", "breath"]
to include all three. 

Example code:

```python
from wildgram import wildgram
tokens, ranges = wildgram("and was beautiful")
#tokens -- the wildgram tokens
#ranges -- a list of tuples, the ith tuple has the start and end indexes for the ith wildgram
print(tokens, ranges) #["beautiful"], [(8, 17)]
```
That's all folks!
